*------------------------------------------------------------------------
* RmcTest.PRG                                  R.W. Seiler  March 7, 2008
*  Functional samples and tests using RmChart from RmChart.com
*  for use with: FiveWin for Harbour (FWH) and xHarbour
*
*  Must link Rmchart.lib and Rmc4Fwh.prg in compile (RmcTest.rc is optional), 
*  and must use Rmchart.dll with the app exe.
*------------------------------------------------------------------------
/*

Functions and procedures in this prg:

  // The app's primary function...
FUNCTION Main()

  // Create the app's main menu system...
STATIC FUNCTION BuildMenu()

  // Create child window upon which to display a graph...
STATIC FUNCTION MakeChWnd()

  // Test some RmChart functions...
PROCEDURE TestChart()

  // Mandate app exit...
PROCEDURE Exit()

  // The procedure to be performed upon every exit of the app...
EXIT PROCEDURE EndAll()

  // XBase++ requirement...
PROCEDURE AppSys  

*/
#include "FiveWin.ch"
#include "Rmchart.ch"
#include "Mylib.ch"    // - because Keylib.ch will not work with Clipper.

#define TAB   CHR(9)
#command QUIT => ( PostQuitMessage( 0 ), __Quit() ) // suggested by Enrico


STATIC ;
       aBack     := {}         ,;
       cAppTitle := ""         ,;
       cPath     := ""         ,;
       hRmcDll   := 0          ,;
       nCtrlId   := 0          ,;
       nWleft    := 0          ,;
       nWtop     := 0          ,;
       oBrush                  ,;
       oWnd                    ,;
       oWndCh

//---------------------------------------------------------------------------//
  // The app's primary function...
FUNCTION Main()

   cPath  := CurDrive()+":\"+CurDir()
   nWleft := 6
   nWtop  := 3

   hRmcDll  := LoadLibrary( "RMCHART.DLL" )

   SETHandle(hRmcDll)  // Send hRmcDll to Rmc4Fwh.prg

   SET _3DLOOK ON

   DEFINE BRUSH oBrush COLOR GetSysColor(15)

   DEFINE WINDOW oWnd FROM 3, 6 TO 45, 120 ;
      TITLE "RmChart Test" ;
      BRUSH oBrush;
      MENU  BuildMenu();
      MDI


   @ 2, 3 SAY "Testing RmChart" COLORS CLR_BLACK, GetSysColor(15)
   
   ACTIVATE WINDOW oWnd  ;
     ON INIT( MakeChWnd() ) 

   oBrush:End()

RETURN nil

//------------------------------- end Main() --------------------------------//
  // Create the app's main menu system...
STATIC FUNCTION BuildMenu()

   local oMenu,cRmcFile := ""
   static lHide := .f.

   MENU oMenu
      MENUITEM "&Tests Menu"
      MENU
         MENUITEM   "&Select Graph File"                         ;
            ACTION   cRmcFile := RTRIM(cGetFile( cPath+"\*.rmc", ;
                                       "Select a graph file" )), ;
                     TestChart(cRmcFile )                        ;
            MESSAGE "Select graph file."

         MENUITEM   "S&imple Chart Test"               ;
            ACTION  TestChart(cPath+"\SimpleBar.rmc" ) ;
            MESSAGE "Run simple bar chart test."

         MENUITEM   "&4 Regions Test"                  ;
            ACTION  TestChart(cPath+"\4_regions.rmc" ) ;
            MESSAGE "Run 4 regions chart test."

         MENUITEM   "&Hide or Show graph"                      ;
            ACTION  IF(!lHide,(oWndCh:Hide(),lHide := .t.),    ;
                              (oWndCh:Show(),SysRefresh(),     ;
                               RMC_Draw(nCtrlId),lHide := .f.) ;
                       )                                       ;
            MESSAGE "Hide or show graph."

         MENUITEM   "E&xit"  ;
            ACTION  Exit()   ;
            MESSAGE "Exit this application."

      ENDMENU
   ENDMENU

RETURN oMenu
//---------------------------------------------------------------------------//
  // Create child window upon which to display a graph...
STATIC FUNCTION MakeChWnd()

   DEFINE WINDOW oWndCh MDICHILD OF oWnd    ;
          FROM 2, 2 TO 37, 110              ;
          STYLE nOr(WS_CHILD)               ;
          COLOR "N/W"

*          BRUSH oBrush ; // Nevermind. Allow default color for contrast so
                          // we can see if oWndCh is displaying as it should.
   ACTIVATE WINDOW oWndCh

RETURN nil
//---------------------------------------------------------------------------//
  // Test some Rmchart functions...
PROCEDURE TestChart(cRMCfile)
LOCAL ;
      cFarProc    := ""              ,;
      nExportOnly := 0               ,;
      nHeight     := 0               ,;
      nParentHndl := oWnd:hWnd       ,;
      nRet        := 0               ,;
      nWidth      := 0               ,;
      nX          := 0               ,;
      nY          := 0               ,;
      sRMCfile    := cRMCfile

LOCAL aRMC_CAPTION := {},nRegion := 1,aCaption := {}

LOCAL nBackColor := CLR_HGRAY,nTextColor := CLR_BLACK,nFontSize := 10,;
      nIsBold := 1,sText := "TEST CAPTION"

LOCAL sCaption := "TEST CAPTION    ",;
      nTitelBackColor := CLR_HGRAY  ,;
      nTitelTextColor := CLR_BLACK  ,;
      nTitelFontSize  := 14         ,;
      nTitelIsBold    := 1

MsgGet("Caption","Enter graph caption:",@sCaption)

 // A curiousity: a multi-dimensional array with only one dimension! Oh well...
aRMC_CAPTION := {{nBackColor,nTextColor,nFontSize,nIsBold,sText}}

aCaption := aRMC_CAPTION[1] // Only used with the array version below of the
                            // AddCaption func, which doesn't work yet.

nCtrlId := oWndCh:hWnd 
nX      := oWndCh:nLeft
nY      := oWndCh:nTop

nCtrlId := nParentHndl

nRet := RMC_GetChartSizeFromFile( sRMCFile, @nWidth, @nHeight  )

/* See results...
      msginfo(nRet,"2: nRet")
      msginfo(nWidth,"nWidth")
      msginfo(nHeight,"nHeight")
*/

/*  // Test if we're able to find the func in the dll...
cFarProc = GetProcAddress( hRmcDll,;
                           "RMC_CREATECHARTFROMFILE",;
                           .t., 7 ,7 ,7 ,7, 7, 2 )

msginfo(cFarProc,"cFarProc")
*/

nRt := RMC_CreateChartFromFile( nParentHndl, nCtrlId, nX, nY, ;
                                nExportOnly, sRMCfile )

*nRt := RMC_AddCaptionI( nCtrlID, nRegion, @aCaption ) // Can't pass array yet.

           // ...so must use the verbose version instead...
nRt := RMC_AddCaption( nCtrlID, nRegion, sCaption, nTitelBackColor, ;
                       nTitelTextColor, nTitelFontSize, nTitelIsBold )
*cc  
*msginfo(nRt,"nRt - RMC_AddCaption")  // nRt should be 0 if func accessed ok

// Now let's display the graph on the child window...
nRt := RMC_Draw(nCtrlId)  

RETURN
//-------------------------- end Startup() ----------------------------------//
  // Mandate app exit...
PROCEDURE Exit()
   IF !EMPTY(oWndCh)
      oWndCh:End()
   ENDIF
   IF !EMPTY(oWnd)
      oWnd:End()
      oBrush:End()
   ENDIF

RETURN
//---------------------------------------------------------------------------//
  // The procedure to be performed upon every exit of the app...
EXIT PROCEDURE EndAll()
LOCAL ;
      cFile     := "" 

*  MsgInfo( "Exit Procedure EndAll()" )

     // Always delete the chart when closing the app!!
   RMC_DeleteChart( nCtrlId )

   FreeLibrary( hRmcDll )
   ResAllFree()
   SysWait(.1)
   CursorArrow()
   Close Databases
   Clear Memory

RETURN

//---------------------------------------------------------------------------//
  // XBase++ requirement
PROCEDURE AppSys  

RETURN

//---------------------------------------------------------------------------//
// Use for testing Rmchart.dll without linking in RMC4FWH.PRG...
/*
      // Use this if you need to get the dimensions of a chart that already
      // exists in an RMC  file (i.e. - if you need the width and height to
      // make the dialog or window upon which you will place the chart)...
DLL32 FUNCTION RMC_GETCHARTSIZEFROMFILE( ;
                 sRMCFile AS LPSTR, ;
                 @nWidth AS PTR, ;
                 @nHeight AS PTR ;
                 ) AS LONG PASCAL LIB hRmcDll

      // Use this to read the chart specs into memory of a chart that already
      // exists in an RMC file...
DLL32 FUNCTION RMC_CREATECHARTFROMFILE( ;
                 nParentHndl AS LONG, ;  // HWND originally, but must use LONG
                 nCtrlId AS LONG, ;
                 nX AS LONG, ;   // nX and nY tell where the top-left of the
                 nY AS LONG, ;   // chart is to be placed on your control (or window).
                 nExportOnly AS LONG, ;
                 sRMCFile AS LPSTR ;
                 ) AS LONG PASCAL LIB hRmcDll

      // Use to change or add a caption to the graph...
DLL32 FUNCTION RMC_ADDCAPTION( ;        
                 nCtrlID AS LONG, ;
                 nRegion AS LONG, ; 
                 sCaption AS LPSTR, ;
                 nTitelBackColor AS LONG, ;
                 nTitelTextColor AS LONG, ;
                 nTitelFontSize AS LONG, ;
                 nTitelIsBold AS LONG ;
                 ) AS LONG PASCAL LIB hRmcDll 

/*
  This "array version" doesn't work yet in FWH...
DLL32 FUNCTION RMC_ADDCAPTIONI( ;   // RMC_AddCaptionI
                 nCtrlID AS LONG, ;
                 nRegion AS LONG, ;
                 @T AS tRMC_CAPTION PTR ;          
                 ) AS LONG PASCAL LIB "RMCHART.DLL" 
*/

      // Use this to display a chart that has been read into memory, on top of
      // whatever control, window or dialog that you want...
DLL32 FUNCTION RMC_DRAW( ;
                 nCtrlId AS LONG ;
                 ) AS LONG PASCAL LIB hRmcDll

// These and about 160 other Rmchart functions are in RMC4FWH.PRG

*/
*--------------------------------------
